==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/client/connection_string_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/client/connection_string.h"

#include "mongo/unittest/unittest.h"

namespace mongo {
namespace {

using unittest::assertGet;

TEST(ConnectionString, EqualityOperatorStandalone) {
    const auto cs = assertGet(ConnectionString::parse("TestHostA:12345"));
    ASSERT(cs == assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT_FALSE(cs != assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT(cs != assertGet(ConnectionString::parse("TestHostB:12345")));
    ASSERT_FALSE(cs == assertGet(ConnectionString::parse("TestHostB:12345")));
}

TEST(ConnectionString, EqualityOperatorReplicaSet) {
    const auto cs = assertGet(ConnectionString::parse("TestRS/TestHostA:12345,TestHostB:12345"));
    ASSERT(cs == assertGet(ConnectionString::parse("TestRS/TestHostA:12345,TestHostB:12345")));
    ASSERT_FALSE(cs == assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT_FALSE(cs ==
                 assertGet(ConnectionString::parse("TestRS/TestHostB:12345,TestHostA:12345")));
    ASSERT_FALSE(cs ==
                 assertGet(ConnectionString::parse("TestRS1/TestHostA:12345,TestHostB:12345")));
}

}  // namespace
}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/client/connection_string_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include <fmt/format.h>

#include "mongo/base/status.h"
#include "mongo/client/connection_string.h"
#include "mongo/unittest/assert.h"
#include "mongo/unittest/framework.h"

namespace mongo {
namespace {

using unittest::assertGet;

TEST(ConnectionString, EqualityOperatorStandalone) {
    const auto cs = assertGet(ConnectionString::parse("TestHostA:12345"));
    ASSERT(cs == assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT_FALSE(cs != assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT(cs != assertGet(ConnectionString::parse("TestHostB:12345")));
    ASSERT_FALSE(cs == assertGet(ConnectionString::parse("TestHostB:12345")));
}

TEST(ConnectionString, EqualityOperatorReplicaSet) {
    const auto cs = assertGet(ConnectionString::parse("TestRS/TestHostA:12345,TestHostB:12345"));
    ASSERT(cs == assertGet(ConnectionString::parse("TestRS/TestHostA:12345,TestHostB:12345")));
    ASSERT_FALSE(cs == assertGet(ConnectionString::parse("TestHostA:12345")));
    ASSERT_FALSE(cs ==
                 assertGet(ConnectionString::parse("TestRS/TestHostB:12345,TestHostA:12345")));
    ASSERT_FALSE(cs ==
                 assertGet(ConnectionString::parse("TestRS1/TestHostA:12345,TestHostB:12345")));
}

}  // namespace
}  // namespace mongo
